@@ -565,10 +565,6 @@ draw_cb (GtkDrawingArea *drawing_area,
 		 cairo_t *cr,
 		 gpointer  user_data)
 {
-	GtkWidget *widget;
-
-	widget = GTK_WIDGET (drawing_area);
-
 	update_relative_sizes (EOG_PRINT_PREVIEW (user_data));
 
 	eog_print_preview_draw (EOG_PRINT_PREVIEW (user_data), cr);
@@ -578,7 +574,6 @@ draw_cb (GtkDrawingArea *drawing_area,
 			 cairo_status_to_string (cairo_status (cr)));
 	}
 
-	gdk_window_get_pointer (gtk_widget_get_window (widget), NULL, NULL, NULL);
 	return TRUE;
 }
 
@@ -1009,7 +1004,6 @@ eog_print_preview_draw (EogPrintPreview *preview, cairo_t *cr)
 	GtkWidget *area;
 	GtkAllocation allocation;
 	gint x0, y0;
-	GtkStyle *style;
 	gboolean has_focus;
 
 	priv = preview->priv;
@@ -1017,17 +1011,15 @@ eog_print_preview_draw (EogPrintPreview *preview, cairo_t *cr)
 
 	has_focus = gtk_widget_has_focus (area);
 
-	style = gtk_widget_get_style (area);
-
 	gtk_widget_get_allocation (area, &allocation);
 
 	/* draw the page */
- 	gdk_cairo_set_source_color (cr, &style->white);
+	cairo_set_source_rgb (cr, 1., 1., 1.);
  	cairo_rectangle (cr, 0, 0, allocation.width, allocation.height);
  	cairo_fill (cr);
 
 	/* draw the page margins */
-	gdk_cairo_set_source_color (cr, &style->black);
+	cairo_set_source_rgb (cr, 0., 0., 0.);
 	cairo_set_line_width (cr, 0.1);
 	cairo_rectangle (cr,
 			 priv->l_rmargin, priv->t_rmargin,
@@ -1069,9 +1061,11 @@ eog_print_preview_draw (EogPrintPreview *preview, cairo_t *cr)
 	}
 
 	if (has_focus) {
-		gtk_paint_focus (style, cr,
-				 GTK_STATE_NORMAL, NULL, NULL,
-				 0, 0, allocation.width, allocation.height);
+		GtkStyleContext *ctx;
+
+		ctx = gtk_widget_get_style_context (area);
+		gtk_render_focus (ctx, cr, x0, y0,
+				  priv->r_width, priv->r_height);
 	}
 }
 
